@@ -7,7 +7,7 @@ use parent qw/Exporter/;
 
 our @EXPORT    = qw/strike strike_search strike_imdb/;
 our @EXPORT_OK = (@EXPORT, 'strike_query');
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 our $BASE_URL = 'https://getstrike.net/api/v2';
 
 use JSON::MaybeXS qw/decode_json/;
@@ -70,7 +70,7 @@ __END__
 
 =head1 NAME
 
-WebService::Strike - Get torrent info from getstrike.net API
+WebService::Strike - [OBSOLETE] Get torrent info from the now-discontinued getstrike.net API
 
 =head1 SYNOPSIS
 
@@ -95,6 +95,9 @@ WebService::Strike - Get torrent info from getstrike.net API
 
 =head1 DESCRIPTION
 
+B<The API was discontinued. The code in this module remains, but it
+does not achieve any useful purpose.>
+
 Strike API is a service for getting information about a torrent given
 its info hash. WebService::Strike is a wrapper for this service.
 
