@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use parent qw/Class::Accessor::Fast/;
 
-our $VERSION = 0.005;
+our $VERSION = 0.006;
 
 use JSON::MaybeXS qw/decode_json/;
 use MIME::Base64;
@@ -71,7 +71,7 @@ __END__
 
 =head1 NAME
 
-WebService::Strike::Torrent - Class representing information about a torrent
+WebService::Strike::Torrent - [OBSOLETE] Class representing information about a torrent
 
 =head1 SYNOPSIS
 
@@ -101,6 +101,9 @@ WebService::Strike::Torrent - Class representing information about a torrent
 
 =head1 DESCRIPTION
 
+B<The API was discontinued. The code in this module remains, but it
+does not achieve any useful purpose.>
+
 WebService::Strike::Torrent is a class that represents information
 about a torrent.
 
